Available on crate feature
ckb-types only.Structs
- QueryIter
Constants
- Default buffer size, it is used to load data from syscall. The default value is set to 256, which will be enough for most cases:
Functions
- Exec a cell in cell dep.
- Find cell by data_hash
- Get inherited file descriptors.
- Load cell
- Load cell capacity
- Load cell data
- Load cell data hash
- Load cell lock
- Load cell lock hash
- Load cell occupied capacity
- Load cell type
- Load cell type hash
- Load header
- Load header epoch length
- Arguments
- Load header epoch start block number
- Load input
- Load input out point
- Load input since
- Load script
- Load script hash
- Load transaction
- Load tx hash
- Load witness
- Load witness args
- Look for a dep cell with specific code hash, code_hash should be a buffer with 32 bytes.
- Spawn a cell in cell dep.