ckb_std::syscalls

Function spawn

pub fn spawn(
    index: usize,
    source: Source,
    place: usize,
    bounds: usize,
    spgs: &mut SpawnArgs,
) -> Result<u64, SysError>
Available on non-crate feature native-simulator only.
The parent process calls the Spawn system call, which creates a new process (a child process) that is an independent ckb-vm instance. It’s important to note that the parent process will not be blocked by the child process as a result of this syscall. Note: available after ckb2023.

Arguments

  • index, source, bounds and place - same as exec.
  • spgs - spawn arguments.

Returns success or a syscall error.