Function ckb_std::high_level::exec_cell
source · [−]pub fn exec_cell(
code_hash: &[u8],
hash_type: ScriptHashType,
offset: u32,
length: u32,
argv: &[&CStr]
) -> Result<u64, SysError>Expand description
Exec a cell in cell dep.
Arguments
code_hash- the code hash to search cell in cell deps.hash_type- the hash type to search cell in cell deps.