pub fn write(fd: u64, buffer: &[u8]) -> Result<usize, SysError>Available on non-crate feature
native-simulator only.Expand description
This syscall writes data to a pipe via a file descriptor. The syscall Write writes up to value pointed by length bytes from the buffer, and the actual length of data written is returned. Note: available after ckb2023.